@@ -60,9 +60,6 @@ public:
     };
     Q_ENUM(CursorMode)
 
-    ScreencastingStream *createOutputStream(KWayland::Client::Output *output, CursorMode mode);
-    ScreencastingStream *createWindowStream(KWayland::Client::PlasmaWindow *window, CursorMode mode);
-    ScreencastingStream *createWindowStream(const QString &uuid, CursorMode mode);
     ScreencastingStream *createVirtualMonitorStream(const QString &name, const QSize &resolution, qreal dpr, CursorMode mode);
 
     void setup(zkde_screencast_unstable_v1 *screencasting);
